@@ -1,8 +1,8 @@
 package Hessian::Deserializer;
 
 use Moose::Role;
-use version; our $VERSION = qv('0.0.1');
 use YAML;
+##use Smart::Comments;
 
 with qw/
   Hessian::Deserializer::Numeric
@@ -16,10 +16,9 @@ has 'input_handle' => (    #{{{
     isa     => 'GlobRef',
     clearer => 'clear_input_handle',
     lazy    => 1,
-    default => sub {
+    default => sub {#{{{
         my $self = shift;
         my $input_handle;
-#        my $input_string = $self->{input_string};
         my $input_string = $self->input_string();
         if ($input_string) {
             open $input_handle, "<", \$input_string
@@ -27,7 +26,7 @@ has 'input_handle' => (    #{{{
                 error => "Unable to read from string input." );
             return $input_handle;
         }
-    }
+    }#}}}
 );    #}}}
 
 after 'input_string' => sub {    #{{{
@@ -37,7 +36,6 @@ after 'input_string' => sub {    #{{{
     # process. input handle should then re-initialize itself the next time it
     # is called.
     $self->clear_input_handle();
-#    delete $self->{input_handle} if $self->{input_handle};
 };    #}}}
 
 before qw/deserialize_data deserialize_message/ => sub {    #{{{
@@ -77,7 +75,7 @@ sub next_token {    #{{{
 sub process_message {    #{{{
     my $self = shift;
     my $tokens;
-    while ( my $token = $self->next_token() ) {
+    while ( my $token = $self->deserialize_message()) { #next_token() ) {
         if ( ( ref $token ) eq 'HASH' ) {
             my @token_keys = keys %{$token};
             @{$tokens}{@token_keys} = @{$token}{@token_keys};
